@@ -92,7 +92,7 @@ class PathItem(BaseModel):
     """
 
     class Config:
-        allow_population_by_field_name = True,
+        allow_population_by_field_name = True
         schema_extra = {
             "examples": [
                 {
